package de.fraunhofer.iem.app

import de.fraunhofer.iem.app.configuration.InitialProjects
import de.fraunhofer.iem.app.logger.getLogger
import de.fraunhofer.iem.app.repository.dto.RepositoryConsentDto
import de.fraunhofer.iem.app.repository.service.RepositoryService
import de.fraunhofer.iem.app.tool.service.ToolService
import de.fraunhofer.iem.app.toolRun.service.ToolRunService
import kotlinx.coroutines.*
import org.springframework.boot.context.event.ApplicationReadyEvent
import org.springframework.context.event.EventListener
import org.springframework.stereotype.Component

@Component
class StartUpHandler(
    val toolRunService: ToolRunService,
    val initialProjects: InitialProjects,
    val toolService: ToolService,
    val repositoryService: RepositoryService,
) {
    private val logger = getLogger(javaClass)
    val coroutineScope = CoroutineScope(Dispatchers.Default)

    @EventListener(ApplicationReadyEvent::class)
    suspend fun queryProjects() {
        withContext(Dispatchers.IO) {
            logger.info("Creating tools in db")
            toolService.createAllTools()
        }
        logger.info("Loading initial projects $initialProjects")

        val jobs = initialProjects.projectIds.mapNotNull { projectId ->
            return@mapNotNull if (projectId >= 0) {
                coroutineScope.launch {
                    toolRunService.createToolRunForRepository(projectId).join()
                    repositoryService.updateVisualizationConsent(projectId, RepositoryConsentDto(true))
                }
            } else {
                null
            }
        }
        coroutineScope.launch {
            jobs.joinAll()
        }
    }

}
