package de.fraunhofer.iem.app.kpi.service

import de.fraunhofer.iem.app.kpi.dto.KPITreeChildResponseDto
import de.fraunhofer.iem.app.kpi.dto.KPITreeResponseDto
import de.fraunhofer.iem.kpiCalculator.core.KpiCalculator
import de.fraunhofer.iem.kpiCalculator.model.kpi.RawValueKpi
import de.fraunhofer.iem.kpiCalculator.model.kpi.hierarchy.DefaultHierarchy
import de.fraunhofer.iem.kpiCalculator.model.kpi.hierarchy.KpiResultHierarchy
import org.springframework.stereotype.Service

@Service
class KPIService {

    fun calculateKpiHierarchy(rawValueKpis: List<RawValueKpi>): KpiResultHierarchy {
        return KpiCalculator.calculateKpis(DefaultHierarchy.get(), rawValueKpis)
    }

    fun removeKPIChildrenLowerThanSecondLevel(kpiTreeResponseDto: KPITreeResponseDto): KPITreeResponseDto {
        val children: List<KPITreeChildResponseDto> = kpiTreeResponseDto.children.map {
            KPITreeChildResponseDto(
                kpi = KPITreeResponseDto(
                    value = it.kpi.value,
                    name = it.kpi.name,
                    description = it.kpi.description,
                    isRoot = it.kpi.isRoot,
                    displayValue = it.kpi.displayValue,
                    emptyList(),
                    it.kpi.isEmpty,
                    order = it.kpi.order
                ),
                actualWeight = it.actualWeight,
                plannedWeight = it.plannedWeight
            )
        }

        return KPITreeResponseDto(
            value = kpiTreeResponseDto.value,
            name = kpiTreeResponseDto.name,
            description = kpiTreeResponseDto.description,
            isRoot = true,
            displayValue = kpiTreeResponseDto.displayValue,
            children = children,
            isEmpty = kpiTreeResponseDto.isEmpty,
            order = kpiTreeResponseDto.order
        )
    }

}
