package de.fraunhofer.iem.app.tool.enumeration

import de.fraunhofer.iem.app.kpi.enumeration.getName
import de.fraunhofer.iem.app.tool.dto.ToolDto
import de.fraunhofer.iem.kpiCalculator.model.kpi.KpiId

//XXX: this can be refactored once we have a list of supported tools in the library
enum class ToolType {
    ORT {
        override fun toViewModel(): ToolDto {
            return ToolDto(
                name = this.getName(),
                relevantKpis = listOf(
                    KpiId.MAXIMAL_VULNERABILITY.getName(),
                    KpiId.VULNERABILITY_SCORE.getName(),
                    KpiId.SECURITY.getName()
                ),
                description = "The OSS Review Toolkit (ORT) provides information about dependencies." +
                    "For more information see https://github.com/oss-review-toolkit/ort.",
                toolType = ORT
            )
        }

        override fun getName(): String {
            return "ORT"
        }
    },
    OCCMD {
        override fun toViewModel(): ToolDto {
            return ToolDto(
                name = this.getName(),
                relevantKpis = listOf(
                    KpiId.SECURITY.getName(),
                    KpiId.PROCESS_TRANSPARENCY.getName(),
                    KpiId.PROCESS_COMPLIANCE.getName(),
                    KpiId.SECRETS.getName(),
                    KpiId.COMMENTS_IN_CODE.getName(),
                    KpiId.DOCUMENTATION.getName(),
                    KpiId.SAST_USAGE.getName(),
                    KpiId.CHECKED_IN_BINARIES.getName()
                ),
                description = "The OCCMD provides various information about the analyzed project." +
                    "For more information see https://gitlab.opencode.de/opencode-analyzer/occmd-public.",
                toolType = OCCMD

            )
        }

        override fun getName(): String {
            return "OCCMD"
        }
    },
    Gitlab {
        override fun toViewModel(): ToolDto {
            return ToolDto(
                name = this.getName(),
                relevantKpis = listOf(
                    KpiId.PROCESS_TRANSPARENCY.getName(),
                    KpiId.PROCESS_COMPLIANCE.getName(),
                    KpiId.NUMBER_OF_COMMITS.getName(),
                    KpiId.NUMBER_OF_SIGNED_COMMITS.getName(),
                    KpiId.DOCUMENTATION.getName(),
                ),
                description = "The Gitlab API is used to derive information about, e.g., the project's compliance" +
                    "to OpenCoDE's platform rules.",
                toolType = Gitlab
            )
        }

        override fun getName(): String {
            return "Gitlab API"
        }
    };

    abstract fun toViewModel(): ToolDto
    abstract fun getName(): String
}
