package de.fraunhofer.iem.app.tool.service

import de.fraunhofer.iem.app.tool.dto.CreateToolDto
import de.fraunhofer.iem.app.tool.entity.ToolEntity
import de.fraunhofer.iem.app.tool.repository.ToolRepository
import de.fraunhofer.iem.app.tools.gitlab.service.RepositoryDetailsService
import de.fraunhofer.iem.app.tools.occmd.service.OccmdService
import de.fraunhofer.iem.app.tools.ort.service.OrtService
import org.springframework.stereotype.Service
import org.springframework.transaction.annotation.Propagation
import org.springframework.transaction.annotation.Transactional

@Service
class ToolService(
    private val toolRepository: ToolRepository,
    private val ortService: OrtService,
    private val occmdService: OccmdService,
    private val repositoryDetailsService: RepositoryDetailsService
) {

    @Transactional(readOnly = false, propagation = Propagation.REQUIRES_NEW)
    fun createAllTools() {
        findOrCreateTool(ortService.getToolDto())
        findOrCreateTool(occmdService.getToolDto())
        findOrCreateTool(repositoryDetailsService.getToolDto())
    }


    fun findToolByName(tool: CreateToolDto): ToolEntity? {
        return toolRepository.findByNameIgnoreCase(
            tool.name
        )
    }


    fun findOrCreateTool(tool: CreateToolDto): ToolEntity {
        return toolRepository.findByNameIgnoreCase(
            tool.name
        )
            ?: toolRepository.save(tool.asDbObject())
    }
}
