package de.fraunhofer.iem.app.utilities

import io.ktor.client.*
import io.ktor.client.engine.cio.*
import io.ktor.client.plugins.contentnegotiation.*
import io.ktor.serialization.kotlinx.json.*
import jakarta.annotation.PreDestroy
import kotlinx.serialization.json.Json
import org.springframework.stereotype.Component

/**
 * Wrapper class for ktor's HttpClient
 */
@Component
class HttpClientWrapper {

    private val client = HttpClient(CIO) {
        install(ContentNegotiation) {
            json(
                Json { ignoreUnknownKeys = true }
            )
        }
    }

    /**
     * Performs a get request to the given url.
     */
    fun getClient(): HttpClient {
        return client
    }

    @PreDestroy
    fun close() {
        client.close()
    }
}
